@@ -28,7 +28,7 @@ from datashape.predicates import isscalar
 import datashape
 import itertools
 
-from into import into
+from odo import into
 from ..dispatch import dispatch
 from ..expr import (Projection, Field, Sort, Head, Broadcast, Selection,
                     Reduction, Distinct, Join, By, Summary, Label, ReLabel,
