@@ -24,19 +24,27 @@ rec = symbol('s', '3 * var * {name: string, amount: int}')
 recx = nd.array([[('Alice', 1), ('Bob', 2)],
                  [('Charlie', 3)],
                  [('Dennis', 4), ('Edith', 5), ('Frank', 6)]],
-                type = str(rec.dshape))
+                type=str(rec.dshape))
 
 
 def test_symbol():
     assert eq(compute(n, nx), nx)
 
+
 def test_slice():
     assert eq(compute(n[0], nx), nx[0])
     assert eq(compute(n[0, :3], nx), nx[0, :3])
 
+
+def test_first_last():
+    assert eq(compute(n[0], nx), nx[0])
+    assert eq(compute(n[-1], nx), nx[-1])
+
+
 def test_field():
     assert eq(compute(rec.amount, recx), recx.amount)
 
+
 def test_arithmetic():
     # assert eq(compute(n + 1, nx), nx + 1)
     assert eq(compute(rec.amount + 1, recx), recx.amount + 1)
