@@ -103,6 +103,9 @@ def test_reductions():
     assert compute(count(t['amount']), data) == 3
     assert compute(any(t['amount'] > 150), data) is True
     assert compute(any(t['amount'] > 250), data) is False
+    assert compute(t.amount[0], data) == 100
+    assert compute(t.amount[-1], data) == 50
+
 
 def test_1d_reductions_keepdims():
     for r in [sum, min, max, nunique, count]:
@@ -575,6 +578,16 @@ def test_summary_by():
                                             ('Bob', 1, 201)])
 
 
+def test_summary_by_first():
+    expr = by(t.name, amt=t.amount[0])
+    assert set(compute(expr, data)) == set((('Bob', 200), ('Alice', 100)))
+
+
+def test_summary_by_last():
+    expr = by(t.name, amt=t.amount[-1])
+    assert set(compute(expr, data)) == set((('Bob', 200), ('Alice', 50)))
+
+
 def test_reduction_arithmetic():
     expr = t.amount.sum() + 1
     assert compute(expr, data) == 351
@@ -693,6 +706,21 @@ def test_slice():
     assert list(compute(t.name[:2], data)) == [data[0][0], data[1][0]]
 
 
+def test_negative_slicing():
+    assert list(compute(t[-1:], data)) == data[-1:]
+    assert list(compute(t[-1:], iter(data))) == data[-1:]
+    assert list(compute(t[-1], data)) == data[-1]
+    assert list(compute(t[-1], iter(data))) == data[-1]
+    assert list(compute(t[-2], data)) == data[-2]
+    assert list(compute(t[-2], iter(data))) == data[-2]
+
+
+@pytest.mark.xfail(raises=ValueError,
+                   reason="No support for stop and step having negative values")
+def test_negative_slicing_raises_on_stop_and_step_not_None():
+    assert list(compute(t[-2:-5:-1], data)) == data[-2:-5:-1]
+
+
 def test_multi_dataset_broadcast():
     x = symbol('x', '3 * int')
     y = symbol('y', '3 * int')
