@@ -44,8 +44,10 @@ def isvalid_identifier(s, regex=re.compile('^[_a-zA-Z][_a-zA-Z0-9]*$')):
     True
     >>> isvalid_identifier('for')
     False
+    >>> isvalid_identifier(None)
+    False
     """
-    return not keyword.iskeyword(s) and regex.match(s) is not None
+    return not not s and not keyword.iskeyword(s) and regex.match(s) is not None
 
 
 def valid_identifier(s):
@@ -119,8 +121,10 @@ class Expr(Node):
     def fields(self):
         if isinstance(self.dshape.measure, Record):
             return self.dshape.measure.names
-        if hasattr(self, '_name'):
+        name = getattr(self, '_name', None)
+        if name is not None:
             return [self._name]
+        return []
 
     def _len(self):
         try:
@@ -254,7 +258,7 @@ class Symbol(Expr):
         self._token = token
 
     def __str__(self):
-        return self._name
+        return self._name or ''
 
     def _resources(self):
         return dict()
