@@ -2,8 +2,7 @@ from __future__ import absolute_import, division, print_function
 
 import datashape
 import datetime
-from datashape import (discover, Tuple, Record, dshape, Fixed, DataShape,
-    to_numpy_dtype, isdimension, var)
+from datashape import discover, Tuple, Record, DataShape, var
 from datashape.predicates import iscollection, isscalar, isrecord
 from pandas import DataFrame, Series
 import itertools
@@ -13,9 +12,10 @@ import warnings
 from collections import Iterator
 
 from .expr import Expr, Symbol, ndim
+from .utils import ignoring
 from .dispatch import dispatch
-from into import into, resource
-from .compatibility import _strtypes, unicode
+from odo import into, resource
+from .compatibility import _strtypes
 
 __all__ = ['Data', 'Table', 'into', 'to_html']
 
@@ -36,14 +36,14 @@ except ImportError:
     pass
 
 
-def Data(data, dshape=None, name=None, fields=None, columns=None,
-         schema=None, **kwargs):
+def Data(data, dshape=None, name=None, fields=None, columns=None, schema=None,
+         **kwargs):
     sub_uri = ''
     if isinstance(data, _strtypes):
         if '::' in data:
             data, sub_uri = data.split('::')
-        data = resource(data, schema=schema, dshape=dshape,
-                              columns=columns, **kwargs)
+        data = resource(data, schema=schema, dshape=dshape, columns=columns,
+                        **kwargs)
     if (isinstance(data, Iterator) and
             not isinstance(data, tuple(not_an_iterator))):
         data = tuple(data)
@@ -54,7 +54,7 @@ def Data(data, dshape=None, name=None, fields=None, columns=None,
         fields = columns
     if schema and dshape:
         raise ValueError("Please specify one of schema= or dshape= keyword"
-                " arguments")
+                         " arguments")
     if schema and not dshape:
         dshape = var * schema
     if dshape and isinstance(dshape, _strtypes):
@@ -76,8 +76,6 @@ def Data(data, dshape=None, name=None, fields=None, columns=None,
             dshape = DataShape(*(dshape.shape + (schema,)))
 
     ds = datashape.dshape(dshape)
-
-    name = name or next(names)
     result = InteractiveSymbol(data, ds, name)
 
     if sub_uri:
@@ -127,7 +125,9 @@ class InteractiveSymbol(Symbol):
     def __init__(self, data, dshape, name=None):
         self.data = data
         self.dshape = dshape
-        self._name = name or next(names)
+        self._name = name or (next(names)
+                              if isrecord(dshape.measure)
+                              else None)
 
     def _resources(self):
         return {self: self.data}
@@ -192,7 +192,7 @@ def concrete_head(expr, n=10):
 
 
 def repr_tables(expr, n=10):
-    result = concrete_head(expr, n)
+    result = concrete_head(expr, n).rename(columns={None: ''})
 
     if isinstance(result, (DataFrame, Series)):
         s = repr(result)
@@ -201,7 +201,7 @@ def repr_tables(expr, n=10):
             s = '\n'.join(s.split('\n')[:-1]) + '\n...'
         return s
     else:
-        return repr(result) # pragma: no cover
+        return repr(result)  # pragma: no cover
 
 
 def numel(shape):
@@ -211,6 +211,7 @@ def numel(shape):
         return 1
     return reduce(lambda x, y: x * y, shape, 1)
 
+
 def short_dshape(ds, nlines=5):
     s = datashape.coretypes.pprint(ds)
     lines = s.split('\n')
@@ -226,6 +227,21 @@ def coerce_to(typ, x):
         return into(typ, x)
 
 
+def coerce_scalar(result, dshape):
+    if 'float' in dshape:
+        return coerce_to(float, result)
+    elif 'int' in dshape:
+        return coerce_to(int, result)
+    elif 'bool' in dshape:
+        return coerce_to(bool, result)
+    elif 'datetime' in dshape:
+        return coerce_to(datetime.datetime, result)
+    elif 'date' in dshape:
+        return coerce_to(datetime.date, result)
+    else:
+        return result
+
+
 def expr_repr(expr, n=10):
     # Pure Expressions, not interactive
     if not expr._resources():
@@ -233,26 +249,15 @@ def expr_repr(expr, n=10):
 
     # Scalars
     if ndim(expr) == 0 and isscalar(expr.dshape):
-        result = compute(expr)
-        if 'float' in str(expr.dshape):
-            return repr(coerce_to(float, result))
-        elif 'int' in str(expr.dshape):
-            return repr(coerce_to(int, result))
-        elif 'bool' in str(expr.dshape):
-            return repr(coerce_to(bool, result))
-        elif 'datetime' in str(expr.dshape):
-            return repr(coerce_to(datetime, result))
-        elif 'date' in str(expr.dshape):
-            return repr(coerce_to(date, result))
-        else:
-            return repr(compute(expr))
+        return repr(coerce_scalar(compute(expr), str(expr.dshape)))
 
     # Tables
-    if ndim(expr) == 1:
-        return repr_tables(expr, 10)
+    with ignoring(Exception):
+        if ndim(expr) == 1:
+            return repr_tables(expr, 10)
 
     # Smallish arrays
-    if ndim(expr) >= 2 and  numel(expr.shape) and numel(expr.shape) < 1000000:
+    if ndim(expr) >= 2 and numel(expr.shape) and numel(expr.shape) < 1000000:
         return repr(compute(expr))
 
     # Other
@@ -309,6 +314,7 @@ Expr.__repr__ = expr_repr
 Expr._repr_html_ = lambda x: to_html(x)
 Expr.__len__ = table_length
 
+
 def intonumpy(data, dtype=None, **kwargs):
     # TODO: Don't ignore other kwargs like copy
     result = into(np.ndarray, data)
